/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2009 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 *****************************************************************************/

#ifndef BODY_LIST_H
#define BODY_LIST_H
//-----------------------------------------------------------------------------
#include "include/base.h"
#include <WORMUX_singleton.h>
#include <map>
#include <string>
//-----------------------------------------------------------------------------
class Body;

class BodyList : public Singleton<BodyList>
{
private:
  std::map<std::string, Body*> list;

  void Load (const std::string &name);

  BodyList();
  friend class Singleton<BodyList>;

public:
  void FreeMem();
  Body* GetBody(const std::string &body);
};

//-----------------------------------------------------------------------------
#endif
